Package: so.ii
Title: data processing capabilities for the so.ii observatory
Version: 1.0.40.0
Authors@R: 
    c(
        person(given = "Frédéric",
            family = "Grelot",
            role = c("aut", "cre"),
            email = "frederic.grelot@inrae.fr",
            comment = c(ORCID = "0000-0003-2638-8114")),
        person(given = "David",
            family = "Nortes Martinez",
            role = c("aut"),
            email = "david.nortes-martinez@inrae.fr",
            comment = c(ORCID = "0000-0002-0711-5885"))
    )
Description: This package collects some very useful utilities to work in a
    collaborative way within team so-ii of G-eau.
URL: https://floodam.org/so.ii
License: GPL (>= 3)
Encoding: UTF-8
Depends: R (>= 4.1.0)
LazyData: true
Imports: data.table, kableExtra, knitr, leaflet, htmltools, methods,
        readODS, rio, scales, sf, terra
Suggests: rmarkdown, testthat (>= 3.0.0)
Roxygen: list(markdown = TRUE)
VignetteBuilder: knitr
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-23 15:10:33 UTC; keluo
Author: Frédéric Grelot [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2638-8114>),
  David Nortes Martinez [aut] (ORCID:
    <https://orcid.org/0000-0002-0711-5885>)
Maintainer: Frédéric Grelot <frederic.grelot@inrae.fr>
