# so.ii <img src="man/figures/logo.png" align="right" width="25%" height="25%"/>

## Welcome to so.ii

`so.ii` is an R library designed for analysis and spatial data processing for flood risk and vulnerability assessment in the [so-ii observatory](https://so-ii.org).

## What **so.ii** can do

In essence, the so.ii R library provides the data processing capabilities needed to support the so-ii observatory's goal of observing flood impacts in a detailed, continuous, comprehensive, and multidisciplinary manner for a better understanding of flood risk:

Core functionalities:

- Spatial Data Analysis
- Data Processing
- Relevant datasets in the context of the [so-ii observatory](https://so-ii.org)

The so.ii library is under active development. New features are added and/or improved as the so.ii team or its collaborators detect the need or new analyses are implemented.

<!-- ## What **so.ii** cannot do -->

## How to get **so.ii**?

You can download and install it from this archive: [www.floodam.org/library/so.ii_1.0.40.0.tar.gz](http://www.floodam.org/library/so.ii_1.0.40.0.tar.gz).

For instance, in a linux environment, you can use those bash instructions:

```
R -e "install.packages(
    pkgs = 'http://www.floodam.org/library/so.ii_1.0.40.0.tar.gz',
    type = 'source',
    repos = NULL,
    dependencies = TRUE)"
```

## How to help for the development of **so.ii**?

Contact us.
