#' Write Interview Transcript to File
#'
#' This function writes an interview transcript (represented as a
#' character vector) to a text file. Each element of the vector
#' becomes a line in the output file.
#'
#' @param interview A character vector containing the lines of the
#'   interview transcript.
#' @param filename The path to the text file where the 
#'   transcript will be written.
#'
#' @return None (invisible NULL). This function writes directly to a
#'   file.
#'
#' @examples
#' # Write an interview transcript to "processed_interview.md"
#' write_interview(intrw, tempfile("interview", fileext = ".md"))
#'
#' @family process interview
#' 
#' @export

write_interview = function(interview, filename){
    writeLines(interview, filename)
}