#' Read Interview Transcript from File
#'
#' This function reads an interview transcript from a text file,
#' returning the content as a character vector where each element
#' represents a line in the file.
#'
#' @param file The path to the text file containing the 
#'   interview transcript.
#'
#' @return A character vector containing the lines of the 
#'   interview transcript.
#'
#' @examples
#' # Read an interview from "interview.txt"
#' interview = read_interview(
#'      file.path(
#'          system.file("extdata", package = "so.ii"), 
#'          "interview.txt"
#'      )
#' )
#' 
#' @family process interview
#'
#' @export

read_interview = function(file){
    interview = readLines(file)
    return(interview)
}