% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kable_units.R
\encoding{UTF-8}
\name{kable_units}
\alias{kable_units}
\title{Replace kable with some useful}
\usage{
kable_units(x, linesep, align = NULL, read = NULL, ...)
}
\arguments{
\item{x}{data.frame or path to a file}

\item{linesep}{integer, position of linesep}

\item{align}{character,}

\item{read}{function how to read the file}

\item{...}{some parameters that will be used by other functions}
}
\value{
A character vector of the table source code.
}
\description{
Replace kable with some useful
}
\examples{

temp = head(iris)[c(5, 1:4)]
temp[["Species"]] = as.character(temp[["Species"]])
kable_units(head(temp))
temp = rbind(temp, c(Species = "mean", as.list(colMeans(temp[-1]))))
kable_units(temp, -1)
temp = rbind(temp, c("units", "mm", "mm", "mm", "mm"))
kable_units(temp, -1)
}
