% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unlist_processed_interview.R
\name{unlist_processed_interview}
\alias{unlist_processed_interview}
\title{Unlist Processed Interview Data with Speaker Tags}
\usage{
unlist_processed_interview(processed_interview)
}
\arguments{
\item{processed_interview}{A list where each element is a string
containing the concatenated intervention of one speaker (as
returned by \code{process_structured_interview}).}
}
\value{
A character vector where each element represents a line of
dialogue, with the corresponding speaker tag prepended. The
format is "\[Speaker Name\] Intervention text".
}
\description{
This function takes a processed interview (as returned by
\code{process_structured_interview}) and reconstructs the original
dialogue format by prepending speaker tags to each intervention.
}
\examples{
# Example Usage:
speakers = retrieve_speaker(intrw)
pattern = generate_speaker_pattern(speakers)
structured_interview = prep_interview(intrw)
processed_interview = process_structured_interview(
     structured_interview, 
     pattern
)
# processed_interview = unlist_processed_interview(processed_interview)

}
\seealso{
Other process interview:
\code{\link[=concatenate_intervention]{concatenate_intervention()}},
\code{\link[=generate_speaker_pattern]{generate_speaker_pattern()}},
\code{\link[=prep_interview]{prep_interview()}},
\code{\link[=process_interview]{process_interview()}},
\code{\link[=process_structured_interview]{process_structured_interview()}},
\code{\link[=read_interview]{read_interview()}},
\code{\link[=rename_speaker]{rename_speaker()}},
\code{\link[=retrieve_speaker]{retrieve_speaker()}},
\code{\link[=structure_interview]{structure_interview()}},
\code{\link[=write_interview]{write_interview()}}
}
\concept{process interview}
