% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generate_blank_report.R
\name{generate_blank_report}
\alias{generate_blank_report}
\title{Generate a blank Quarto book report}
\usage{
generate_blank_report(path, cover = c("generic", "gt-amc", "soii", "student"))
}
\arguments{
\item{path}{Character. Destination folder for the template. If missing
or \code{NULL}, a temporary directory is used and a warning is issued.}

\item{cover}{Character. Type of cover page. Allowed values are:
\code{"generic"}, \code{"gt-amc"}, \code{"soii"} and \code{"student"}. Default to \code{"generic"}.}
}
\value{
nothing
}
\description{
Copies an empty Quarto book template from the \strong{so.ii} package into a
user‑specified directory and inserts a cover page.
}
\details{
The function copies a quarto report template available in the folder
\code{extdata/template/empty_quarto_book} of this package. The
function also copies the LaTeX scripts needed to correctly format the
document (cover file included -\code{titlepage.tex}-). The necessary folder tree
is created in \code{path} to store all the files. Two informative messages are
printed before and after the copying process.
}
\examples{
\dontrun{
# Default call – uses a temporary folder and the "generic" cover
generate_blank_report()

# Custom folder with the "gt-amc" cover
report_path = file.path(tempdir(), "my_report")
generate_blank_report(path = report_path, cover = "gt-amc")
}

}
