% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/estimate_catnat_freq.R
\encoding{UTF-8}
\name{estimate_catnat_freq}
\alias{estimate_catnat_freq}
\title{Estimate frequency of Cat Nat events}
\usage{
estimate_catnat_freq(commune, period, hazard, period_format = "\%Y")
}
\arguments{
\item{commune}{factor, commune}

\item{period}{POSIXct, a date for the event}

\item{hazard}{factor, type of hazard}

\item{period_format}{character, format to extract information from period}
}
\value{
array fivving frequency of Cat Nat events with 3 dimensions
(commune, period, hazard)
}
\description{
Estimate frequency of Cat Nat events
}
\examples{

\dontrun{
# To be added (soon)
}
}
