% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/add_bar.R
\encoding{UTF-8}
\name{add_bar}
\alias{add_bar}
\title{Add a bar to a map}
\usage{
add_bar(bar_d = NULL, bar_xy = NULL, bar_adj = NULL, bar_lon = 0.4788987, ...)
}
\arguments{
\item{bar_d}{integer, size of the bar in km.}

\item{bar_xy}{either a character or a vector giving the position of the bar in
the plot.}

\item{bar_adj}{numeric of length 2, adjustment for text placement.}

\item{bar_lon}{numeric of length 1, may be adjusted for some plots with
trial-and-error strategy.}

\item{...}{some unused parameters.}
}
\value{
NULL.
}
\description{
Add a bar to a map
}
\details{
Correct some things in sbar from terra to add scale bar to plots.
}
\examples{

\dontrun{
library(sf)
plot(so_ii_collectivity[0])
add_bar(bar_d = 10, bar_xy = c(3.55, 43.47), bar_adj = c(0.5, -1))
}
}
