% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{so_ii_scope}
\alias{so_ii_scope}
\title{Local collectivities included in so-ii}
\format{
a vector of 78 INSEE code
}
\usage{
so_ii_scope
}
\description{
A dataset containing the INSEE code of all local collectivities
(communes) included in so-ii
}
\keyword{datasets}
