% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/write_interview.R
\name{write_interview}
\alias{write_interview}
\title{Write Interview Transcript to File}
\usage{
write_interview(interview, filename)
}
\arguments{
\item{interview}{A character vector containing the lines of the
interview transcript.}

\item{filename}{The path to the text file where the
transcript will be written.}
}
\value{
None (invisible NULL). This function writes directly to a
file.
}
\description{
This function writes an interview transcript (represented as a
character vector) to a text file. Each element of the vector
becomes a line in the output file.
}
\examples{
# Write an interview transcript to "processed_interview.md"
write_interview(intrw, tempfile("interview", fileext = ".md"))

}
\seealso{
Other process interview:
\code{\link[=concatenate_intervention]{concatenate_intervention()}},
\code{\link[=generate_speaker_pattern]{generate_speaker_pattern()}},
\code{\link[=prep_interview]{prep_interview()}},
\code{\link[=process_interview]{process_interview()}},
\code{\link[=process_structured_interview]{process_structured_interview()}},
\code{\link[=read_interview]{read_interview()}},
\code{\link[=rename_speaker]{rename_speaker()}},
\code{\link[=retrieve_speaker]{retrieve_speaker()}},
\code{\link[=structure_interview]{structure_interview()}},
\code{\link[=unlist_processed_interview]{unlist_processed_interview()}}
}
\concept{process interview}
