% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_density.R
\encoding{UTF-8}
\name{plot_density}
\alias{plot_density}
\title{Plot a sf or sfc object with hatching}
\usage{
plot_density(x, density = NULL, angle = 45, col = NA, border = NULL)
}
\arguments{
\item{x}{sf or sfc object}

\item{density}{numeric, the density of shading lines, in lines per inch.}

\item{angle}{numeric, the slope of shading lines, given as an angle in degrees
(counter-clockwise).}

\item{col}{character, the color of the shading lines.}

\item{border}{character, the color to draw the border.}
}
\value{
Nothing useful.
}
\description{
Plot a sf or sfc object with hatching
}
\details{
The function makes a call to \code{polygon()} after some transformations of the sf
(or sfc) object. It will plot something only if all geometry types of x are
'MULTIPOLYGON'. In the other case, it will just send a warning.

All rendering parameters can be set for original number of features. More
details are to be found in \code{polygon()} help.
}
\examples{

map_so_ii()
plot_density(so_ii_collectivity)
plot_density(
 so_ii_collectivity,
 density = c(10,20),
 col = c("black", "blue", "green"),
 border = "gray",
 angle = seq(nrow(so_ii_collectivity))
)
}
