% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{so_ii_catnat}
\alias{so_ii_catnat}
\title{Number of Cat Nat events for the municipalities of so-ii}
\format{
array with 3 dimensions
\describe{
\item{first}{commune as in so_ii_scope}
\item{second}{year of Cat Nat events}
\item{third}{type of hazard}
}
}
\source{
\url{https://www.georisques.gouv.fr/donnees/bases-de-donnees/base-gaspar} # nolint
}
\usage{
so_ii_catnat
}
\description{
A dataset containing the number of Cat Nat events (linked to flood) by year
and so-ii municipality according to the GASPAR database.
}
\details{
Last update: 2023-10-17
}
\keyword{datasets}
