% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{so_ii_montpellier}
\alias{so_ii_montpellier}
\title{Spatial definition of districts of Montpellier city}
\format{
sf data.frame 31 rows, 2 variables
\describe{
\item{district}{character, id of each district as given by montpellier3m}
\item{district_name}{character, name of each district}
\item{district_group}{character, how districts are grouped by montpellier3m}
}
}
\source{
\url{https://data.montpellier3m.fr/dataset/sous-quartiers-de-montpellier}
}
\usage{
so_ii_montpellier
}
\description{
A dataset containing the spatial definition of all districts
for Montpellier.
}
\keyword{datasets}
