% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read_interview.R
\name{read_interview}
\alias{read_interview}
\title{Read Interview Transcript from File}
\usage{
read_interview(file)
}
\arguments{
\item{file}{The path to the text file containing the
interview transcript.}
}
\value{
A character vector containing the lines of the
interview transcript.
}
\description{
This function reads an interview transcript from a text file,
returning the content as a character vector where each element
represents a line in the file.
}
\examples{
# Read an interview from "interview.txt"
interview = read_interview(
     file.path(
         system.file("extdata", package = "so.ii"), 
         "interview.txt"
     )
)

}
\seealso{
Other process interview:
\code{\link[=concatenate_intervention]{concatenate_intervention()}},
\code{\link[=generate_speaker_pattern]{generate_speaker_pattern()}},
\code{\link[=prep_interview]{prep_interview()}},
\code{\link[=process_interview]{process_interview()}},
\code{\link[=process_structured_interview]{process_structured_interview()}},
\code{\link[=rename_speaker]{rename_speaker()}},
\code{\link[=retrieve_speaker]{retrieve_speaker()}},
\code{\link[=structure_interview]{structure_interview()}},
\code{\link[=unlist_processed_interview]{unlist_processed_interview()}},
\code{\link[=write_interview]{write_interview()}}
}
\concept{process interview}
