% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/retrieve_speaker.R
\name{retrieve_speaker}
\alias{retrieve_speaker}
\title{Retrieve Unique Speakers from Interview Transcript}
\usage{
retrieve_speaker(interview)
}
\arguments{
\item{interview}{A character vector representing the interview
transcript (as returned by \code{read_interview}). The lines should
be tagged with speaker names within square brackets
(e.g., "[Speaker1] This is a line").}
}
\value{
A character vector containing the unique speaker identifiers
found in the interview transcript.
}
\description{
This function identifies and returns a vector of unique speaker
identifiers present in an interview transcript. It first structures
the transcript using \code{structure_interview} to extract speaker names.
}
\examples{
# Example usage:
speakers = retrieve_speaker(intrw)

}
\seealso{
Other process interview:
\code{\link[=concatenate_intervention]{concatenate_intervention()}},
\code{\link[=generate_speaker_pattern]{generate_speaker_pattern()}},
\code{\link[=prep_interview]{prep_interview()}},
\code{\link[=process_interview]{process_interview()}},
\code{\link[=process_structured_interview]{process_structured_interview()}},
\code{\link[=read_interview]{read_interview()}},
\code{\link[=rename_speaker]{rename_speaker()}},
\code{\link[=structure_interview]{structure_interview()}},
\code{\link[=unlist_processed_interview]{unlist_processed_interview()}},
\code{\link[=write_interview]{write_interview()}}
}
\concept{process interview}
