% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/concatenate_intervention.R
\name{concatenate_intervention}
\alias{concatenate_intervention}
\title{Concatenate and Clean Intervention Text}
\usage{
concatenate_intervention(intervention, pattern)
}
\arguments{
\item{intervention}{A character vector containing individual
intervention strings.}

\item{pattern}{The regular expression pattern to be removed from
each intervention string.}
}
\value{
A single string created by concatenating the cleaned
intervention strings with spaces in between.
}
\description{
This function concatenates a vector of intervention strings after
removing a specified regular expression pattern from each string.
This is often used to remove speaker tags before combining multiple
interventions into a single text block.
}
\examples{
# Example usage:
speakers = retrieve_speaker(intrw)
pattern = generate_speaker_pattern(speakers)
structured_interview = prep_interview(intrw)
concatenated_text = so.ii:::concatenate_intervention(
     structured_interview[[1]], 
     pattern
)

}
\seealso{
Other process interview:
\code{\link[=generate_speaker_pattern]{generate_speaker_pattern()}},
\code{\link[=prep_interview]{prep_interview()}},
\code{\link[=process_interview]{process_interview()}},
\code{\link[=process_structured_interview]{process_structured_interview()}},
\code{\link[=read_interview]{read_interview()}},
\code{\link[=rename_speaker]{rename_speaker()}},
\code{\link[=retrieve_speaker]{retrieve_speaker()}},
\code{\link[=structure_interview]{structure_interview()}},
\code{\link[=unlist_processed_interview]{unlist_processed_interview()}},
\code{\link[=write_interview]{write_interview()}}
}
\concept{process interview}
\keyword{internal}
