% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/format_presence.R
\encoding{UTF-8}
\name{format_presence}
\alias{format_presence}
\title{Transform ods table presence in md table (for Mattermost)}
\usage{
format_presence(x)
}
\arguments{
\item{x}{character or data.frame, path of the ods table or the table itself}
}
\value{
character, md version of table behind x.
}
\description{
Transform ods table presence in md table (for Mattermost)
}
