% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{clc_color}
\alias{clc_color}
\title{Color and label for CLC}
\format{
data.frame 5 rows, 3 variables
}
\usage{
clc_color
}
\description{
A dataset proposing default colors and labels for plotting CLC
}
\keyword{datasets}
