% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{so_ii_inset}
\alias{so_ii_inset}
\title{Inset to help localisation of the so-ii perimeter}
\format{
sf data.frame 5 rows, 1 variable
\describe{
\item{scope}{character, names of the scope}
}
}
\source{
\url{http://bdtopage.eaufrance.fr/page/objectifs}
}
\usage{
so_ii_inset
}
\description{
A sf dataset containing 4 simplified geometries of France, Occitanie,
Hérault, and so-ii perimeter. rownames are provided with "nation", "region",
"department", "so.ii".
}
\keyword{datasets}
