% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kable.R
\encoding{UTF-8}
\name{kable}
\alias{kable}
\title{Replace kable from kniter with some useful preset options}
\usage{
kable(data, ...)
}
\arguments{
\item{data}{object, something to be transform in a table}

\item{...}{some parameters that will be used in original kable}
}
\value{
Somthing to be used as a table in latex format
}
\description{
Replace kable from kniter with some useful preset options
}
\examples{

temp = head(iris)[c(5, 1:4)]
temp[["Species"]] = as.character(temp[["Species"]])
kable(temp)
temp = rbind(temp, c(Species = "mean", as.list(colMeans(temp[-1]))))
kable(temp, -1)
temp = rbind(temp, c("units", "mm", "mm", "mm", "mm"))
kable(temp, -1)
}
