% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{so_ii_limit}
\alias{so_ii_limit}
\title{Spatial perimeter of so-ii}
\format{
sfc_POLYGON of length 1
}
\usage{
so_ii_limit
}
\description{
A dataset containing the perimeter of so-ii.
}
\details{
Basically, this dataset is obtained as
\code{sf::st_union(so_ii_commune)}
}
\keyword{datasets}
