% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{so_ii_population}
\alias{so_ii_population}
\title{Population for so-ii}
\format{
numeric matrix 78 rows, 33 columns
\describe{
\item{row}{commune as in so_ii_scope}
\item{column}{year}
}
}
\source{
\url{https://www.insee.fr/fr/statistiques/2522602}
}
\usage{
so_ii_population
}
\description{
A dataset containing the population of commune in so-ii according to INSEE.
}
\keyword{datasets}
