% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{so_ii_hydro}
\alias{so_ii_hydro}
\title{Hydrographic network within the so-ii perimeter}
\format{
sf data.frame 125 rows, 4 variables
\describe{
\item{id}{id, from BD TOPAGE (corresponding to CdOh)}
\item{name}{character, name of the hydrographic elements in the BD TOPAGE}
\item{degre}{factor, level of importance of the hydrographic element
used to plot the hydrographic network with different levels of
detail ("1", "2", "3").}
\item{type}{factor, type of hydrographic element ("canal", "river",
"waterbody")}
}
}
\source{
\url{http://bdtopage.eaufrance.fr/page/objectifs}
}
\usage{
so_ii_hydro
}
\description{
A dataset containing the official hydrographic network from the BD TOPAGE
within the so-ii perimeter.
}
\keyword{datasets}
