% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/process_structured_interview.R
\name{process_structured_interview}
\alias{process_structured_interview}
\title{Process Structured Interview Data to Extract Interventions}
\usage{
process_structured_interview(structured_interview, pattern)
}
\arguments{
\item{structured_interview}{A list where each element is a character
vector representing an intervention by a specific speaker (as
returned by \code{prep_interview}).}

\item{pattern}{The regular expression pattern used to remove
speaker tags from the interventions. Typically generated using
\code{generate_speaker_pattern}.}
}
\value{
A list where each element is a single string containing
the concatenated intervention of one speaker, with speaker tags
removed. The names of the list elements are the unique speaker IDs.
}
\description{
This function processes a structured interview (as created by
\code{prep_interview}) to extract and concatenate the interventions of
each speaker. It removes speaker tags from each segment and then
simplifies the naming of the resulting list elements.
}
\examples{
# Example Usage:
speakers = retrieve_speaker(intrw)
pattern = generate_speaker_pattern(speakers)
structured_interview = prep_interview(intrw)
processed_interview = process_structured_interview(
     structured_interview, 
     pattern
)

}
\seealso{
Other process interview:
\code{\link[=concatenate_intervention]{concatenate_intervention()}},
\code{\link[=generate_speaker_pattern]{generate_speaker_pattern()}},
\code{\link[=prep_interview]{prep_interview()}},
\code{\link[=process_interview]{process_interview()}},
\code{\link[=read_interview]{read_interview()}},
\code{\link[=rename_speaker]{rename_speaker()}},
\code{\link[=retrieve_speaker]{retrieve_speaker()}},
\code{\link[=structure_interview]{structure_interview()}},
\code{\link[=unlist_processed_interview]{unlist_processed_interview()}},
\code{\link[=write_interview]{write_interview()}}
}
\concept{process interview}
