% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prep_interview.R
\name{prep_interview}
\alias{prep_interview}
\title{Prepare Structured Interview Data}
\usage{
prep_interview(interview)
}
\arguments{
\item{interview}{A character vector representing the interview
transcript (as returned by \code{read_interview}).}
}
\value{
A list where each element is a character vector containing
a contiguous block of lines spoken by the same speaker.  The
names of the list elements uniquely identify each segment based
on speaker ID, segment number and length.
}
\description{
This function takes a raw interview transcript, structures it by
speaker using \code{structure_interview}, and then organizes the lines
into a list where each element corresponds to a segment spoken by
a specific speaker.  Each segment is named according to the
speaker's ID, sequence number, and length of the segment.
}
\examples{
# Example usage:
structured_interview = prep_interview(intrw)

}
\seealso{
Other process interview:
\code{\link[=concatenate_intervention]{concatenate_intervention()}},
\code{\link[=generate_speaker_pattern]{generate_speaker_pattern()}},
\code{\link[=process_interview]{process_interview()}},
\code{\link[=process_structured_interview]{process_structured_interview()}},
\code{\link[=read_interview]{read_interview()}},
\code{\link[=rename_speaker]{rename_speaker()}},
\code{\link[=retrieve_speaker]{retrieve_speaker()}},
\code{\link[=structure_interview]{structure_interview()}},
\code{\link[=unlist_processed_interview]{unlist_processed_interview()}},
\code{\link[=write_interview]{write_interview()}}
}
\concept{process interview}
