% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{so_ii_clc}
\alias{so_ii_clc}
\title{CLC information for so-ii}
\format{
sf data.frame 1337 rows, 2 variables
\describe{
\item{clc_2018}{character, classification from CLC 2018}
\item{color}{character, default color to be used to plot so_ii_clc}
}
}
\usage{
so_ii_clc
}
\description{
A dataset containing the Corine Land Cover information on so-ii.
}
\keyword{datasets}
