% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/current_version.R
\encoding{UTF-8}
\name{current_version}
\alias{current_version}
\title{Find the current version of some data}
\usage{
current_version(path, ...)
}
\arguments{
\item{path}{character path to a directory where to find data}

\item{...}{some extra parameters that will be passed to dir(path, ...)}
}
\value{
character path of the file corresponding the current version of the data
}
\description{
Find the current version of some data
}
\examples{

\dontrun{
# To be added (soon)
}
}
