% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{intrw}
\alias{intrw}
\title{Conversational transcript between two participants}
\format{
A vector of 18 strings with the following format: each line is tagged
with the speaker's name enclosed in square brackets. Each of the vector's
elements can be either complete phrases or segments of longer phrases
}
\source{
Provided by package authors.
}
\usage{
intrw
}
\description{
A short fictional dialogue between two friends. The data are
presented as a vector of strings.
}
\keyword{datasets}
